@@ -61,9 +61,9 @@ struct _GStringChunk
  * @v1: a key. 
  * @v2: a key to compare with @v1.
  * 
- * Compares two strings and returns %TRUE if they are equal.
- * It can be passed to g_hash_table_new() as the @key_equal_func
- * parameter, when using strings as keys in a #GHashTable.
+ * Compares two strings for byte-by-byte equality and returns %TRUE 
+ * if they are equal. It can be passed to g_hash_table_new() as the 
+ * @key_equal_func parameter, when using strings as keys in a #GHashTable.
  *
  * Returns: %TRUE if the two keys match.
  */
@@ -124,23 +124,42 @@ nearest_power (gsize base, gsize num)
 /* String Chunks.
  */
 
+/**
+ * g_string_chunk_new:
+ * @size: the default size of the blocks of memory which are 
+ *        allocated to store the strings. If a particular string 
+ *        is larger than this default size, a larger block of 
+ *        memory will be allocated for it.
+ * 
+ * Creates a new #GStringChunk. 
+ * 
+ * Returns: a new #GStringChunk
+ */
 GStringChunk*
-g_string_chunk_new (gsize default_size)    
+g_string_chunk_new (gsize size)    
 {
   GStringChunk *new_chunk = g_new (GStringChunk, 1);
-  gsize size = 1;    
+  gsize actual_size = 1;    
 
-  size = nearest_power (1, default_size);
+  actual_size = nearest_power (1, size);
 
   new_chunk->const_table       = NULL;
   new_chunk->storage_list      = NULL;
-  new_chunk->storage_next      = size;
-  new_chunk->default_size      = size;
-  new_chunk->this_size         = size;
+  new_chunk->storage_next      = actual_size;
+  new_chunk->default_size      = actual_size;
+  new_chunk->this_size         = actual_size;
 
   return new_chunk;
 }
 
+/**
+ * g_string_chunk_free:
+ * @chunk: a #GStringChunk 
+ * 
+ * Frees all memory allocated by the #GStringChunk.
+ * After calling g_string_chunk_free() it is not safe to
+ * access any of the strings which were contained within it.
+ */
 void
 g_string_chunk_free (GStringChunk *chunk)
 {
@@ -162,6 +181,59 @@ g_string_chunk_free (GStringChunk *chunk)
   g_free (chunk);
 }
 
+/**
+ * g_string_chunk_clear:
+ * @chunk: a #GStringChunk
+ *
+ * Frees all strings contained within the #GStringChunk.
+ * After calling g_string_chunk_clear() it is not safe to
+ * access any of the strings which were contained within it.
+ *
+ * Since: 2.14
+ */
+void
+g_string_chunk_clear (GStringChunk *chunk)
+{
+  GSList *tmp_list;
+
+  g_return_if_fail (chunk != NULL);
+
+  if (chunk->storage_list)
+    {
+      for (tmp_list = chunk->storage_list; tmp_list; tmp_list = tmp_list->next)
+        g_free (tmp_list->data);
+
+      g_slist_free (chunk->storage_list);
+
+      chunk->storage_list       = NULL;
+      chunk->storage_next       = chunk->default_size;
+      chunk->this_size          = chunk->default_size;
+    }
+
+  if (chunk->const_table)
+      g_hash_table_remove_all (chunk->const_table);
+}
+
+/**
+ * g_string_chunk_insert:
+ * @chunk: a #GStringChunk
+ * @string: the string to add
+ * 
+ * Adds a copy of @string to the #GStringChunk.
+ * It returns a pointer to the new copy of the string 
+ * in the #GStringChunk. The characters in the string 
+ * can be changed, if necessary, though you should not 
+ * change anything after the end of the string.
+ *
+ * Unlike g_string_chunk_insert_const(), this function 
+ * does not check for duplicates. Also strings added 
+ * with g_string_chunk_insert() will not be searched 
+ * by g_string_chunk_insert_const() when looking for 
+ * duplicates.
+ * 
+ * Returns: a pointer to the copy of @string within 
+ *          the #GStringChunk.
+ */
 gchar*
 g_string_chunk_insert (GStringChunk *chunk,
 		       const gchar  *string)
@@ -171,6 +243,28 @@ g_string_chunk_insert (GStringChunk *chunk,
   return g_string_chunk_insert_len (chunk, string, -1);
 }
 
+/**
+ * g_string_chunk_insert_const:
+ * @chunk:  a #GStringChunk
+ * @string: the string to add
+ * 
+ * Adds a copy of @string to the #GStringChunk, unless 
+ * the same string has already been added to the #GStringChunk 
+ * with g_string_chunk_insert_const().
+ * 
+ * This function is useful if you need to copy a large number 
+ * of strings but do not want to waste space storing duplicates. 
+ * But you must remember that there may be several pointers to 
+ * the same string, and so any changes made to the strings 
+ * should be done very carefully.
+ * 
+ * Note that g_string_chunk_insert_const() will not return a 
+ * pointer to a string added with g_string_chunk_insert(), even 
+ * if they do match.
+ * 
+ * Returns: a pointer to the new or existing copy of @string 
+ *          within the #GStringChunk
+ */
 gchar*
 g_string_chunk_insert_const (GStringChunk *chunk,
 			     const gchar  *string)
@@ -203,8 +297,11 @@ g_string_chunk_insert_const (GStringChunk *chunk,
  * Adds a copy of the first @len bytes of @string to the #GStringChunk. The
  * copy is nul-terminated.
  * 
- * The characters in the string can be changed, if necessary, though you
- * should not change anything after the end of the string.
+ * Since this function does not stop at nul bytes, it is the caller's
+ * responsibility to ensure that @string has at least @len addressable bytes.
+ *
+ * The characters in the returned string can be changed, if necessary, though
+ * you should not change anything after the end of the string.
  * 
  * Return value: a pointer to the copy of @string within the #GStringChunk
  * 
@@ -262,6 +359,18 @@ g_string_maybe_expand (GString* string,
     }
 }
 
+/**
+ * g_string_sized_new:
+ * @dfl_size: the default size of the space allocated to 
+ *            hold the string.
+ *
+ * Creates a new #GString, with enough space for @dfl_size 
+ * bytes. This is useful if you are going to add a lot of 
+ * text to the string and don't want it to be reallocated 
+ * too often.
+ *
+ * Returns: the new #GString.
+ */
 GString*
 g_string_sized_new (gsize dfl_size)    
 {
@@ -277,6 +386,14 @@ g_string_sized_new (gsize dfl_size)
   return string;
 }
 
+/**
+ * g_string_new:
+ * @init: the initial text to copy into the string.
+ * 
+ * Creates a new #GString, initialized with the given string.
+ *
+ * Returns: the new #GString.
+ */
 GString*
 g_string_new (const gchar *init)
 {
@@ -297,6 +414,21 @@ g_string_new (const gchar *init)
   return string;
 }
 
+/**
+ * g_string_new_len:
+ * @init: initial contents of string.
+ * @len: length of @init to use.
+ *
+ * Creates a new #GString with @len bytes of the 
+ * @init buffer.  Because a length is provided, @init 
+ * need not be nul-terminated, and can contain embedded 
+ * nul bytes.
+ *
+ * Since this function does not stop at nul bytes, it is the caller's
+ * responsibility to ensure that @init has at least @len addressable bytes.
+ *
+ * Returns: a new #GString.
+ */
 GString*
 g_string_new_len (const gchar *init,
                   gssize       len)    
@@ -316,6 +448,17 @@ g_string_new_len (const gchar *init,
     }
 }
 
+/**
+ * g_string_free:
+ * @string: a #GString
+ * @free_segment: if %TRUE the actual character data is freed as well
+ *
+ * Frees the memory allocated for the #GString.
+ * If @free_segment is %TRUE it also frees the character data.
+ *
+ * Returns: the character data of @string 
+ *          (i.e. %NULL if @free_segment is %TRUE)
+ */
 gchar*
 g_string_free (GString *string,
 	       gboolean free_segment)
@@ -337,6 +480,17 @@ g_string_free (GString *string,
   return segment;
 }
 
+/**
+ * g_string_equal:
+ * @v: a #GString
+ * @v2: another #GString
+ *
+ * Compares two strings for equality, returning %TRUE if they are equal. 
+ * For use with #GHashTable.
+ *
+ * Returns: %TRUE if they strings are the same 
+ *          length and contain the same bytes.
+ */
 gboolean
 g_string_equal (const GString *v,
                 const GString *v2)
@@ -362,6 +516,14 @@ g_string_equal (const GString *v,
   return TRUE;
 }
 
+/**
+ * g_string_hash:
+ * @str: a string to hash
+ *
+ * Creates a hash code for @str; for use with #GHashTable.
+ *
+ * Returns: hash code for @str
+ */
 /* 31 bit hash function */
 guint
 g_string_hash (const GString *str)
@@ -379,6 +541,19 @@ g_string_hash (const GString *str)
   return h;
 }
 
+/**
+ * g_string_assign:
+ * @string: the destination #GString. Its current contents 
+ *          are destroyed.
+ * @rval: the string to copy into @string
+ *
+ * Copies the bytes from a string into a #GString, 
+ * destroying any previous contents. It is rather like 
+ * the standard strcpy() function, except that you do not 
+ * have to worry about having enough space to copy the string.
+ *
+ * Returns: the destination #GString.
+ */
 GString*
 g_string_assign (GString     *string,
 		 const gchar *rval)
@@ -398,6 +573,15 @@ g_string_assign (GString     *string,
   return string;
 }
 
+/**
+ * g_string_truncate:
+ * @string: a #GString
+ * @len: the new size of the #GString
+ *
+ * Cuts off the end of the GString, leaving the first @len bytes. 
+ *
+ * Returns: the #GString
+ */
 GString*
 g_string_truncate (GString *string,
 		   gsize    len)    
@@ -438,6 +622,24 @@ g_string_set_size (GString *string,
   return string;
 }
 
+/**
+ * g_string_insert_len:
+ * @string: a #GString
+ * @pos: position in @string where insertion should 
+ *       happen, or -1 for at the end
+ * @val: bytes to insert
+ * @len: number of bytes of @val to insert
+ * 
+ * Inserts @len bytes of @val into @string at @pos.  
+ * Because @len is provided, @val may contain embedded 
+ * nuls and need not be nul-terminated. If @pos is -1, 
+ * bytes are inserted at the end of the string.
+ *
+ * Since this function does not stop at nul bytes, it is the caller's
+ * responsibility to ensure that @val has at least @len addressable bytes.
+ *
+ * Returns: the #GString
+ */
 GString*
 g_string_insert_len (GString     *string,
 		     gssize       pos,    
@@ -509,6 +711,15 @@ g_string_insert_len (GString     *string,
   return string;
 }
 
+/**
+ * g_string_append:
+ * @string: a #GString.
+ * @val: the string to append onto the end of the #GString.
+ * 
+ * Adds a string onto the end of a #GString, expanding it if necessary.
+ *
+ * Returns: the #GString.
+ */
 GString*
 g_string_append (GString     *string,
 		 const gchar *val)
@@ -519,6 +730,21 @@ g_string_append (GString     *string,
   return g_string_insert_len (string, -1, val, -1);
 }
 
+/**
+ * g_string_append_len:
+ * @string: a #GString
+ * @val: bytes to append
+ * @len: number of bytes of @val to use.
+ * 
+ * Appends @len bytes of @val to @string. 
+ * Because @len is provided, @val may contain 
+ * embedded nuls and need not be nul-terminated.
+ * 
+ * Since this function does not stop at nul bytes, it is the caller's
+ * responsibility to ensure that @val has at least @len addressable bytes.
+ *
+ * Returns: the #GString
+ */
 GString*
 g_string_append_len (GString	 *string,
                      const gchar *val,
@@ -530,6 +756,15 @@ g_string_append_len (GString	 *string,
   return g_string_insert_len (string, -1, val, len);
 }
 
+/**
+ * g_string_append_c:
+ * @string: a #GString.
+ * @c: the byte to append onto the end of the #GString.
+ *
+ * Adds a byte onto the end of a #GString, expanding it if necessary.
+ * 
+ * Returns: the #GString.
+ */
 #undef g_string_append_c
 GString*
 g_string_append_c (GString *string,
@@ -559,6 +794,16 @@ g_string_append_unichar (GString  *string,
   return g_string_insert_unichar (string, -1, wc);
 }
 
+/**
+ * g_string_prepend:
+ * @string: a #GString
+ * @val: the string to prepend on the start of the #GString
+ *
+ * Adds a string on to the start of a #GString, 
+ * expanding it if necessary.
+ *
+ * Returns: the #GString
+ */
 GString*
 g_string_prepend (GString     *string,
 		  const gchar *val)
@@ -569,6 +814,21 @@ g_string_prepend (GString     *string,
   return g_string_insert_len (string, 0, val, -1);
 }
 
+/**
+ * g_string_prepend_len:
+ * @string: a #GString
+ * @val: bytes to prepend
+ * @len: number of bytes in @val to prepend
+ *
+ * Prepends @len bytes of @val to @string. 
+ * Because @len is provided, @val may contain 
+ * embedded nuls and need not be nul-terminated.
+ *
+ * Since this function does not stop at nul bytes, it is the caller's
+ * responsibility to ensure that @val has at least @len addressable bytes.
+ *
+ * Returns: the #GString passed in
+ */
 GString*
 g_string_prepend_len (GString	  *string,
                       const gchar *val,
@@ -580,6 +840,16 @@ g_string_prepend_len (GString	  *string,
   return g_string_insert_len (string, 0, val, len);
 }
 
+/**
+ * g_string_prepend_c:
+ * @string: a #GString
+ * @c: the byte to prepend on the start of the #GString
+ *
+ * Adds a byte onto the start of a #GString, 
+ * expanding it if necessary.
+ *
+ * Returns: the #GString
+ */
 GString*
 g_string_prepend_c (GString *string,
 		    gchar    c)
@@ -608,6 +878,17 @@ g_string_prepend_unichar (GString  *string,
   return g_string_insert_unichar (string, 0, wc);
 }
 
+/**
+ * g_string_insert:
+ * @string: a #GString
+ * @pos: the position to insert the copy of the string
+ * @val: the string to insert
+ *
+ * Inserts a copy of a string into a #GString, 
+ * expanding it if necessary.
+ *
+ * Returns: the #GString
+ */
 GString*
 g_string_insert (GString     *string,
 		 gssize       pos,    
@@ -621,6 +902,16 @@ g_string_insert (GString     *string,
   return g_string_insert_len (string, pos, val, -1);
 }
 
+/**
+ * g_string_insert_c:
+ * @string: a #GString
+ * @pos: the position to insert the byte
+ * @c: the byte to insert
+ *
+ * Inserts a byte into a #GString, expanding it if necessary.
+ * 
+ * Returns: the #GString
+ */
 GString*
 g_string_insert_c (GString *string,
 		   gssize   pos,    
@@ -731,6 +1022,18 @@ g_string_insert_unichar (GString *string,
   return string;
 }
 
+/**
+ * g_string_erase:
+ * @string: a #GString
+ * @pos: the position of the content to remove
+ * @len: the number of bytes to remove, or -1 to remove all
+ *       following bytes
+ *
+ * Removes @len bytes from a #GString, starting at position @pos.
+ * The rest of the #GString is shifted down to fill the gap.
+ *
+ * Returns: the #GString
+ */
 GString*
 g_string_erase (GString *string,
 		gssize   pos,
@@ -900,6 +1203,33 @@ g_string_append_printf_internal (GString     *string,
   g_free (buffer);
 }
 
+/**
+ * g_string_sprintf:
+ * @string: a #GString.
+ * @format: the string format. See the sprintf() documentation.
+ * @Varargs: the parameters to insert into the format string.
+ *
+ * Writes a formatted string into a #GString.
+ * This is similar to the standard sprintf() function,
+ * except that the #GString buffer automatically expands 
+ * to contain the results. The previous contents of the 
+ * #GString are destroyed. 
+ *
+ * Deprecated: This function has been renamed to g_string_printf().
+ */
+
+/**
+ * g_string_printf:
+ * @string: a #GString.
+ * @format: the string format. See the printf() documentation.
+ * @Varargs: the parameters to insert into the format string.
+ *
+ * Writes a formatted string into a #GString.
+ * This is similar to the standard sprintf() function,
+ * except that the #GString buffer automatically expands 
+ * to contain the results. The previous contents of the 
+ * #GString are destroyed.
+ */
 void
 g_string_printf (GString *string,
 		 const gchar *fmt,
@@ -914,6 +1244,30 @@ g_string_printf (GString *string,
   va_end (args);
 }
 
+/**
+ * g_string_sprintfa:
+ * @string: a #GString.
+ * @format: the string format. See the sprintf() documentation.
+ * @Varargs: the parameters to insert into the format string.
+ *
+ * Appends a formatted string onto the end of a #GString.
+ * This function is is similar to g_string_sprintf() except that
+ * the text is appended to the #GString. 
+ *
+ * Deprecated: This function has been renamed to 
+ * g_string_append_printf().
+ */
+
+/**
+ * g_string_append_printf:
+ * @string: a #GString.
+ * @format: the string format. See the printf() documentation.
+ * @Varargs: the parameters to insert into the format string.
+ *
+ * Appends a formatted string onto the end of a #GString.
+ * This function is is similar to g_string_printf() except 
+ * that the text is appended to the #GString.
+ */
 void
 g_string_append_printf (GString *string,
 			const gchar *fmt,
